@@ -285,6 +285,8 @@ class TypeRegistry(BaseTypeRegistry):
         # for each sub field
         for field_name, field in obj.fields.items():
 
+            is_optional = False
+
             if _is_deprecated(field):
                 LOGGER.debug("%s.%s is deprecated - skipping", obj.name, field_name)
                 continue
@@ -310,10 +312,14 @@ class TypeRegistry(BaseTypeRegistry):
 
                 # check for default value
                 if not _is_undefined(field.default_value):
+                    # attribute is optional if it has default value
+                    is_optional = True
                     field_def.update(dict(default=field.default_value))
 
                 # if nullable, make optional
                 elif not isinstance(field.type, GraphQLNonNull):
+                    # attribute is optional if it is nullable
+                    is_optional = True
                     field_def.update(dict(default=None))
 
             # add field definition
@@ -325,6 +331,7 @@ class TypeRegistry(BaseTypeRegistry):
                     attr_name,
                     attr_type=self.get_doc_field_type(field.type),
                     description=field.description,
+                    optional=is_optional,
                 )
             )
 
